//===================  Traitement des donnes (statistique descriptive) ===============//
import settings;                                

// Calcul de la somme des valeurs absolues (donnes discrtes)
int SommeAbsD(int[] D)
{
    int N = D.length;
    int S = 0;
    for(int i=0; i < N; ++i) S += abs(D[i]);
    return S;
}


// Calcul du poids de chaque point (donnes discrtes)
real [] poidsD(int[] D)
{
    int N = D.length;
    real [] W ;
    for(int i=0; i < N; ++i){
    W[i]=abs(D[i])/SommeAbsD(D);
    }
    return W;
}

//  continues

// Calcul de la somme des valeurs absolues (donnes continues)
real SommeAbsC(real[] D)
{
    int N = D.length;
    real S = 0;
    for(int i=0; i < N; ++i) S += abs(D[i]);
    return S;
}

// Calcul du poids de chaque point (donnes continues)
real [] poidsC(real[] D)
{
    int N = D.length;
    real [] W ;
    for(int i=0; i < N; ++i){
    W[i]=abs(D[i])/SommeAbsC(D);
    }
    return W;
}

// =============================      Donnes discrtes     ========================== //
// Calcul des moments.
real Moments(int ordre , real[] D) 
{
    int N = D.length;
    real S = 0;
    for(int i=0; i < N; ++i) S += D[i]^ordre;
    return S/N;
}

// Calcul des moments centrs.
real MomentsC(int ordre , real[] D) 
{
    int N = D.length;
    real S = 0;
    for(int i=0; i < N; ++i) S += (D[i] - Moments(1,D))^ordre;
    return S/N;
}

// Calcul de Skewness
real XSkewness(real[] D) 
{
    real m2 = MomentsC(2,D);
    real m3 = MomentsC(3,D);
    return m3/m2**(3/2);
}

// Calcul de Kurtosis
real XKurtosis(real[] D) 
{
    real m2 = MomentsC(2,D);
    real m4 = MomentsC(4,D);
    return (m4/m2^2)-3;
}

//Tri  bulle croissant des donnes du tableau
void Tri(int[] t, int n) 
{
    int i   = 0;                 
    int j   = 0;                 
    int tmp = 0;                  
    bool en_desordre = true;      
    
    for (i=0; i<n; ++i)
    {
        en_desordre = false;     
        
        for(j=1 ; j<n-i; ++j)
        { 
            if(t[j] < t[j-1])
            {
                tmp = t[j-1];
                t[j-1] = t[j];
                t[j] = tmp;
                en_desordre = true;  
            }
        }
    }
}

//Calcul de la mdiane discrte
real Mediane(int[] D)
{
    int N = D.length;
    real Me;
    
    if (N%2==1) Me = D[(int)((N+1)/2)];              
    else Me = (D[(int)(N/2)] + D[(int)(N/2)+1])/2;   
    return Me;
}

//Calcul de la moyenne gomtrique discrte
real MoyenneGeometrique (int[] D)
{
    int N = D.length;
    real S = 1;
    real M;
    
    for(int i=0; i < N; ++i) if (D[i] > 0) S *= D[i];
    return M = S^(1/N);
}

//Calcul de la moyenne quadratique discrte
real MoyenneQuadratique (int[] D)
{
    int N = D.length;
    real S = 0;
    real M;
    
    for(int i=0; i < N; ++i) S += D[i]^2;
    return M = sqrt(S/N);
}


//Calcul de la moyenne harmonique discrte
real MoyenneHarmonique (int[] D)
{
    int N = D.length;
    real S = 0;
    real M;
    for(int i=0; i < N; ++i) if(D[i]!=0) S = S + 1/D[i];
    return M = N/S;
}


// Calcul du mode discret
real Mode(int[] D)
{
    int N = D.length;
    int max, maxi = 0;
    int[] F;
    real imax = 0;
    
    // Dtermination du plus grand nombre de la srie
    for(int k=0; k < N; ++k) if (maxi <= D[k]) maxi=D[k];
    
    // Initialisation du tableau de taille maxi
    for(int i=0; i <= maxi; ++i) F[i] = 0;
    
    // Groupement des donnes discrtes
    for(int i=0; i <= maxi; ++i)
    {
        for(int j=0; j<N; ++j) if (D[j]==i) F[i] += 1;
        
        // Dtermination du mode
        if (max < F[i]) 
        {
            max = F[i];
            imax = i;
        }
    }
    return imax;
}

//Trac de la fonction de rpartition des Donnes discrtes  
void FdrDiscret(int[] D)
{
    srand(seconds());
    int N = D.length;
    int[] F;
    int max = D[0];
    
    for(int k=0; k<N; ++k) if (max <= D[k]) max=D[k];
    
    for(int i=0; i<=max; ++i)
    {
        F[i]=0;
        for(int j=0; j<N; ++j) if (D[j]==i) F[i] += 1;
        if(i >= 1) F[i] += F[i-1];
    }
    
    for(int i=0; i <= max; ++i)
    {                   
        dot((i,F[i]/N),.7rgb(unitrand(), unitrand(), unitrand()));
        draw((i,0)--(i,F[i]/N),.7rgb(unitrand(), unitrand(), unitrand()));
    }
}

// Trac d'un histogramme pour des Donnes discrtes
void HistD(int[] X)
{
    srand(seconds());
    //unitsize(0.8cm,6cm);
    //size(300,150,IgnoreAspect);
    int nbins;   // Nombre de barres dans l'histogramme
    
    int[]  NB;                  
    real[] NB_norm ;
    int[] Y ;
    real[] a ;    // Abscisse de rectangles
    real[] b;     // Abscisse de rectangles
    int[]  Effectif;
    int[] modalite;
    int kk;
    
    nbins = max(X) - min(X) + 1;   // nombre de rectangles
    
    Y=sort(X);   // X ordonn
    
     for(int i=0; i< nbins; ++i)   // Calcul des effectifs
     {
         NB[i]=0;
         for(int j=0; j<X.length; ++j) if (Y[j]==i) NB[i] += 1;
     }
    
    for(int i=0; i<NB.length; ++i) // On enlve les effectifs  0
     {
         if(NB[i]!=0)
         {
             Effectif[kk] = NB[i];
             modalite[kk] = i;
             kk = kk + 1;
         }
     }
    
    NB_norm = Effectif / max(Effectif);
    
    for(int i=0; i<Effectif.length; ++i)
    {
       a[i] = modalite[i]- 0.35;   
       b[i] = modalite[i]+ 0.35;  
    }

 // Trac
for(int i=0; i < Effectif.length; ++i)                   
    {
        filldraw((a[i],0)--(b[i],0)--(b[i],NB_norm[i])--(a[i],NB_norm[i])--cycle,
        fillpen = rgb(unitrand(), unitrand(), unitrand()),
        drawpen = linewidth(.2mm)+ rgb(unitrand(), unitrand(), unitrand()));
         label(string(Effectif[i]),((a[i] + b[i])/2,NB_norm[i]),N,fontsize(7pt));
         label(string(modalite[i]),((a[i] + b[i])/2,0),S,fontsize(8pt));
    }
    draw ((min(X)-0.8,0)--(max(X)+0.8,0),linewidth(.2mm)+rgb(0.5, 0.5, 0.5));
    //draw ((min(X)-0.8,0)--(min(X)-0.8,max(NB_norm)+0.8),linewidth(.3mm));
}


//Trac du camembert
void Camembert(int[] D)
{
    srand(seconds());
    size(7.5cm,0);
    int[] F,Eff,mod;
    int N = D.length;
    int max = D[0];
    int a;

    for(int k=0; k < N; ++k) if (max <= D[k]) max = D[k];    
    for(int i=0; i<=max; ++i)                                
    {
        F[i]=0;
        for(int j=0; j<N; ++j) if (D[j]==i) F[i] += 1;  
    }
    
    for(int i=0; i<F.length; ++i)  
    {
        if(F[i]!=0)
        {
            Eff[a] = F[i];
            mod[a] = i;
            a = a + 1;
        }
    }
    pen colorand; // Couleur des secteurs
    real[] angle,angleplus,lbl;
    angleplus[0]=0;
    
    for(int i=0; i<Eff.length; ++i) // Trac du camembert
    {
        colorand = rgb(unitrand(),unitrand(),unitrand());
        angle[i] = Eff[i]*360 / sum(Eff);
        angleplus[i+1] = angleplus[i] + angle[i];                                                    
        lbl[i] = angleplus[i] + angle[i]/2;                                                          
        path secteur = (0,0)--arc((0,0), 1, angleplus[i], angleplus[i+1])--cycle;                    
        filldraw(secteur, colorand);                                                                 
        label(format("%i",mod[i]),shift(1.2*dir(lbl[i]))*(0,0),fontsize(8pt)+colorand);              
        label(format("%d",(int)(angle[i]/3.6))+"\%",shift(0.7*dir(lbl[i]))*(0,0),fontsize(6pt)+white);   
    }
    shipout(bbox(3mm,white));
}

// =============================      Donnes qualitatives     ========================== //

//Trac du camembert des donnes qualitatives
void CamembertDQ(int[] D , string[] Nom)
{
    srand(seconds());
    //size(300,250,IgnoreAspect);

    pen colorand; // Couleur des secteurs
    real[] angle,angleplus,lbl;
    angleplus[0]=0;

    for(int i=0; i<D.length; ++i) // Trac du camembert
    {
        colorand = rgb(unitrand(),unitrand(),unitrand());
        angle[i] = D[i]*360 / sum(D);
        angleplus[i+1] = angleplus[i] + angle[i];
        lbl[i] = angleplus[i] + angle[i]/2;
        path secteur = (0,0)--arc((0,0), 1, angleplus[i], angleplus[i+1])--cycle;
        filldraw(secteur, colorand);
        label(Nom[i],shift(1.4*dir(lbl[i]))*(0,0),fontsize(10pt)+white,Fill(colorand));
        //label(format((int)(D[i])),shift(0.7*dir(lbl[i]))*(0,0),fontsize(8pt)+white);
        label(format("%d",D[i]),shift(0.7*dir(lbl[i]))*(0,0),fontsize(8pt)+white);
        draw(0.9*dir(lbl[i]).. 1.2*dir(lbl[i]),.1bp+colorand,ArcArrow);   // flche
    }

    shipout(bbox(3mm,white));
}

//Trac d'histogramme des donnes qualitatives
void HistoDQ(int[] X , string[] Nom)
{
srand(seconds());
size(400,150,IgnoreAspect);
real [] Y;
real[] a;
real[] b;
real [] W = poidsD(X);

// cration des couleurs
real[][] RR = new real[X.length][3];
 for(int i=0; i < X.length; ++i)
 {
    for(int j=0; j < 3; ++j){
      RR[i][j]= unitrand();
    }
 }

Y=X/max(X);  // normalisation des hauteurs des rectangles

for(int i=0; i<X.length; ++i)
    {
    a[i]=2*i/X.length-W[i]/2;
    b[i]=2*i/X.length+W[i]/2;
    }

// Trac
// les rectangles sont d'Abscisse  (a,b) d'hauteur Y
for(int i=0; i < X.length; ++i)
    {
        filldraw((a[i],0)--(b[i],0)--(b[i],Y[i])--(a[i],Y[i])--cycle,
        fillpen = rgb(RR[i][0], RR[i][1], RR[i][2]),
        drawpen = linewidth(.2mm)+ rgb(unitrand(), unitrand(), unitrand()));
         label(string(X[i]),((a[i] + b[i])/2,Y[i]),N,fontsize(7pt));
         label(rotate(45)*Nom[i],((a[i] + b[i])/2,0),S,fontsize(5pt)+rgb(RR[i][0], RR[i][1], RR[i][2]));
    }
draw((min(a)-max(W),0)--(max(b)+max(W),0),linewidth(.2mm)+rgb(0.5, 0.5, 0.5));
//draw((min(a)-max(W),0)--(min(a)-max(W),max(Y)+max(W)),linewidth(.2mm)+rgb(0.5, 0.5, 0.5));
}



// =============================      Donnes continues     ========================== //
//Calcul de la mdiane en continue
real MedianeC(real[] X, int nbins)
{
    if(nbins<10)nbins=10;
    
    int N = X.length;                                            
    real pas = (max(X) - min(X)) / nbins;                        
    real[] extrem = new real[nbins+1];                           
   
    for(int i=0; i<=nbins; ++i) extrem[i] = min(X) + i*pas;      
    int[] F = new int[nbins];                                    
    
    for(int i=0; i< nbins; ++i)                                  
    {
        F[i]=0;
        for(int j=0; j<N; ++j) if (X[j]<=extrem[i+1]&&X[j]>extrem[i]) F[i] += 1;
    }
    
    real[] FdR = new real [nbins];                               
    FdR[0] = F[0];
    for (int i=1; i< nbins; ++i) FdR[i]=FdR[i-1]+F[i];
    for (int i=0; i< nbins; ++i) FdR[i]=FdR[i]/N;                
    
    real e_i   = 0.0;
    real e_i1  = 0.0;
    real Fe_i  = 0.0;
    real Fe_i1 = 0.0;
    for (int i=0; i<nbins; ++i)            
    {
        if(FdR[i]<0.5 && FdR[i+1]>0.5)
        {
            e_i   = extrem[i];
            e_i1  = extrem[i+1];
            Fe_i  = FdR[i];
            Fe_i1 = FdR[i+1]; 
        }
    }
    real Me = 0;  
    if(Fe_i1-Fe_i!=0) Me = ((0.5-Fe_i)/(Fe_i1-Fe_i)) * (e_i1-e_i) + e_i;
    return Me;
}

// Calcul des moments
real MomentsContinu(int ordre , real[] X, int nbins) 
{
    if(nbins<10)nbins=10;
    real pas;                                   
    real[] extrem = new real[nbins+1];           
    real[] NB = new real[nbins];                 
    real[] CentreClasse = new real[nbins];       
    int N = X.length;                            
    real moy = 0;                                
    
    for(int i=0; i<nbins; ++i) NB[i] = 0;        
    pas = (max(X) - min(X)) / nbins;             
    for(int i=0; i<=nbins; ++i) extrem[i] = min(X) + i*pas;  
    for(int i=0; i<nbins; ++i)CentreClasse[i] = (extrem[i] + extrem[i+1]) / 2;  
    for(int j=0; j<X.length; ++j) for(int i=0; i<nbins; ++i) if (X[j]>=min(X)+i*pas && X[j]<min(X)+(i+1)*pas) NB[i] += 1; 
    for(int i=0; i<nbins; ++i) moy += CentreClasse[i]^ordre * NB[i];
    return moy/N;
}

// Calcul des moments centrs
real MomentsContinuC(int ordre , real[] X, int nbins) 
{
    if(nbins<10) nbins = 10;
    real pas;                                       
    real[] extrem = new real[nbins+1];           
    real[] NB = new real[nbins];                
    real[] CentreClasse = new real[nbins];       
    int N = X.length;                            
    real moy = 0;
    
    for(int i=0; i<nbins; ++i) NB[i] = 0;       
    pas = (max(X) - min(X)) / nbins;             
    for(int i=0; i<=nbins; ++i) extrem[i] = min(X) + i*pas;  
    for(int i=0; i<nbins; ++i)CentreClasse[i] = (extrem[i] + extrem[i+1]) / 2;  
    for(int j=0; j<X.length; ++j) for(int i=0; i<nbins; ++i) if (X[j]>=min(X)+i*pas && X[j]<min(X)+(i+1)*pas) NB[i] += 1;  
    for(int i=0; i < nbins; ++i) moy += NB[i]*(CentreClasse[i] - MomentsContinu(1,X,nbins))^ordre;
    return moy/N;
}

// Calcul de Skewness
real XSkewnessC(real[] X, int nbins) 
{   
    real m2 = MomentsContinuC(2,X,nbins);
    real m3 = MomentsContinuC(3,X,nbins);
    return m3/m2**(3/2);
}

// Calcul de Kurtosis
real XKurtosisC(real[] X, int nbins) 
{
    real m2 = MomentsContinuC(2,X,nbins);
    real m4 = MomentsContinuC(4,X,nbins);
    return (m4/m2^2)-3;
}


// Moyenne gometrique pour des Donnes continues
real MoyenneGeometriqueC(real[] X, int nbins)
{
    if(nbins<10)nbins=10;
    real pas;                                    
    real[] extrem = new real[nbins+1];           
    real[] NB = new real[nbins];                 
    real[] CentreClasse = new real[nbins];       
    int N = X.length;                            
    real moy = 1;                                
    
    for(int i=0; i<nbins; ++i) NB[i] = 0;        
    pas = (max(X) - min(X)) / nbins;             
    for(int i=0; i<=nbins; ++i) extrem[i] = min(X) + i*pas;      
    for(int i=0; i<nbins; ++i)CentreClasse[i] = (extrem[i] + extrem[i+1]) / 2; // Centre de chaque classe
    for(int j=0; j<X.length; ++j) for(int i=0; i<nbins; ++i) if(X[j]>=min(X)+i*pas && X[j]<min(X)+(i+1)*pas) NB[i] += 1;  
    for(int i=0; i < nbins; ++i) moy = moy * CentreClasse[i]^NB[i]; // Cumul
    return moy^(1/N);
}


// Moyenne quadratique pour des Donnes continues
real MoyenneQuadratiqueC(real[] X, int nbins)
{
    if(nbins<10)nbins=10;
    real pas;                                    
    real[] extrem = new real[nbins+1];           
    real[] NB = new real[nbins];                 
    real[] CentreClasse = new real[nbins];       
    int N = X.length;                            
    real moy = 0;                                
    
    for(int i=0; i<nbins; ++i)NB[i] = 0;         
    pas = (max(X) - min(X)) / nbins;             
    for(int i=0; i<=nbins; ++i) extrem[i] = min(X) + i*pas;     
    for(int i=0; i<nbins; ++i) CentreClasse[i] = (extrem[i] + extrem[i+1]) / 2;   
    for(int j=0; j<X.length; ++j) for(int i=0; i<nbins; ++i) if (X[j]>=min(X)+i*pas && X[j]<min(X)+(i+1)*pas) NB[i] +=1;  
    for(int i=0; i<nbins; ++i) moy = moy + CentreClasse[i] * CentreClasse[i] * NB[i];     // Cumul
    return sqrt(moy / N);  
}

// Moyenne Harmonique pour des Donnes continues
real MoyenneHarmoniqueC(real[] X, int nbins)
{
    if(nbins<10)nbins=10;
    real pas;                                    
    real[] extrem = new real[nbins+1];           
    real[] NB = new real[nbins];                 
    real[] CentreClasse = new real[nbins];       
    int N = X.length;                            
    real moy = 0;                                
    
    for(int i=0; i<nbins; ++i) NB[i] = 0;        
    pas = (max(X) - min(X)) / nbins;             
    for(int i=0; i<=nbins; ++i) extrem[i] = min(X) + i*pas;  
    for(int i=0; i<nbins; ++i) CentreClasse[i] = (extrem[i] + extrem[i+1]) / 2;  
    for(int j=0; j<X.length; ++j) for(int i=0; i<nbins; ++i) if (X[j]>=min(X)+i*pas && X[j]<min(X)+(i+1)*pas) NB[i] += 1;  
    for(int i=0; i<nbins; ++i) moy = moy + NB[i] / CentreClasse[i]; // Cumul 
    moy /= N;
    return moy^(-1); 
}

// classe modale pour des Donnes continues
real ClasseModale(real[] X, int nbins, int borne)
{
    real pas;                                    
    real[] extrem = new real[nbins+1];           
    int[] NB = new int[nbins];                   
    real[] NB_norm = new real[nbins];            
    real[] CentreClasse = new real[nbins];       
    real classeMod = 0;
    int termeMax = 0;
    
    for(int i=0; i<nbins; ++i) NB[i] = 0;        
    pas = (max(X) - min(X))/nbins;              
    for(int i=0; i<=nbins; ++i) extrem[i] = min(X) + i*pas;  
    for(int i=0; i<nbins; ++i) CentreClasse[i] = (extrem[i] + extrem[i+1]) / 2;  
    for(int j=0; j<X.length; ++j) for(int i=0; i<nbins; ++i) if (X[j]>=extrem[i] && X[j]<extrem[i+1])NB[i] += 1;  
    NB[nbins-1] = NB[nbins-1]+1;                 

    for (int j=0; j<nbins; ++j)
    {
        if (termeMax < NB[j])
        {
            termeMax = NB[j];
            if (borne == 0) classeMod = extrem[j];
            else classeMod = extrem[j+1];
        }
    }
    //return CentreClasse[classeModale] ;
    return classeMod; 
}




//Trac de la fonction de rpartition des Donnes continues
void FdrContinue(real[] X, int nbins)
{
    srand(seconds());
    if(nbins<10)nbins=10;
    
    int N = X.length;                            
    real pas = (max(X) - min(X)) / nbins;        
    real[] extrem = new real[nbins+1];           
    real[] CentreClasse = new real[nbins];       
    
    for(int i=0; i<=nbins; ++i) extrem[i] = min(X) + i*pas;  
    for(int i=0; i<nbins; ++i)CentreClasse[i] = (extrem[i] + extrem[i+1]) / 2;  
    int[] F = new int[nbins];       

    for(int i=0; i< nbins; ++i)     
    {
        F[i]=0;
        for(int j=0; j<N; ++j) if (X[j]<=extrem[i+1]&&X[j]>extrem[i]) F[i] += 1;
    }
    
    real[] FdR = new real [nbins];       
    FdR[0] = F[0];
    for (int i=1; i< nbins; ++i) FdR[i] = FdR[i-1]+F[i];
    for (int i=0; i< nbins; ++i) FdR[i] = FdR[i]/N;  
    for(int i=0; i < nbins; ++i)
    {                   
        dot((CentreClasse[i],FdR[i]),.7rgb(unitrand(), unitrand(), unitrand()));
        if (i < nbins-1) draw((CentreClasse[i],FdR[i])--(CentreClasse[i+1],FdR[i+1]),.7rgb(unitrand(), unitrand(), unitrand()));
    }
}

// Trac d'un histogramme pour des Donnes continues
void HistContinue(real[] X, int nbins)
{
    srand(seconds());
    unitsize(1cm);                                   
    real ecart_max;                                  
    real pas;                                        
    real[] a = new real[nbins+1];                    
    real[] NB = new real[nbins];                     
    real[] NB_norm = new real[nbins];                
    for(int i=0; i<nbins; ++i) NB[i] = 0;            
    ecart_max = max(X) - min(X);                     
    pas = ecart_max/nbins;                          

    for(int i=0; i<=nbins; ++i) a[i] = min(X) + i*pas;      
    for(int j=0; j<X.length; ++j) for(int i=0; i<nbins; ++i) if (X[j]>=min(X)+i*pas && X[j]<min(X)+(i+1)*pas) NB[i] += 1;  
    NB[nbins-1] = NB[nbins-1]+1;              
    for(int i=0; i<nbins; ++i)
    {
        if (max(NB)!= 0) NB_norm[i] = NB[i] / max(NB);  
        else NB_norm[i] = 0;
    }
    
    for(int i=0; i < nbins; ++i) // Trac
    {                   
        filldraw((a[i],0)--(a[i+1],0)--(a[i+1],NB_norm[i])--(a[i],NB_norm[i])--cycle,
        fillpen = rgb(unitrand(), unitrand(), unitrand()),
        drawpen = linewidth(.1mm)+ rgb(unitrand(), unitrand(), unitrand()));
        label(string(NB[i]),((a[i] + a[i+1])/2,NB_norm[i]),N,fontsize(8pt));
    }
}

//  =========================     Fin  Stat descriptive     ========================= //


void EcrireTeX(string fichierS, real[] data, string[] Noms) {
                file ficheS=output(fichierS);
                write(ficheS,"\begin{tabular}{|l c|} \hline",newl);
                write(ficheS,"\multicolumn{2}{|c|}{R\'esultats de l'analyse des donnes}\\ \hline",newl);
                write(ficheS,"\cline{1-2}",newl);
                for(int i=0; i < data.length; ++i){
                write(ficheS,Noms[i]+" &$"+ format("%.6f",data[i])+" $ \\",newl);
                }
                write(ficheS,"\hline",newl);
                write(ficheS,"\end{tabular}",newl);
    }



// Ecrire dans un fichier texte
void EcrireTexte(string fichierS, real[] data) {
                file fout =output(fichierS);

                for(int i=0; i < data.length; ++i){
                write(fout,data[i],tab);
                
                }
    }
// Fin EcrireTexte



// fonction pour crire les rsultats dans un tableau format LaTeX
void EcrireTeXC(string fichierS, real[] data, string[] Noms) {
                int i;
                file ficheS=output(fichierS);
                write(ficheS,"\begin{tabular}{|l c|} \hline",newl);
                write(ficheS,"\multicolumn{2}{|c|}{R\'esultats de l'analyse des donnes}\\ \hline",newl);
                write(ficheS,"\cline{1-2}",newl);
                for(i=0; i < data.length-2; ++i){
                write(ficheS,Noms[i]+" &$"+ format("%.6f",data[i])+" $ \\",newl);
                }
                write(ficheS,Noms[i]+" &$["+ format("%.6f",data[i]) + ";" + format("%.6f",data[i+1]) + "] $ \\\hline",newl);
                write(ficheS,"\end{tabular}",newl);
    }
// Fin EcrireTeXC
